==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Image/Gui/Resources/translations/Image_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Image</source>
      <translation>Görüntü</translation>
    </message>
    <message>
      <source>Create image plane...</source>
      <translation>Görüntü düzlemini oluştur...</translation>
    </message>
    <message>
      <source>Create a planar image in the 3D space</source>
      <translation>3B uzayda düzlemsel bir resim oluştur</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>3B uzayda düzlemsel bir resim oluştur</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <source>Image</source>
      <translation>Görüntü</translation>
    </message>
    <message>
      <source>Open...</source>
      <translation>Aç...</translation>
    </message>
    <message>
      <source>Open image view</source>
      <translation>Resim görünümünü aç</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+318"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Resmi görüntülemek için tanılanamayan bir renk uzayı seçili</translation>
    </message>
    <message>
      <source>Image pixel format</source>
      <translation>Görüntü karecik (piksel) biçimi</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Resmi sığdır</translation>
    </message>
    <message>
      <source>Stretch the image to fit the view</source>
      <translation>Resmi, görünüme sığacak şekilde uzat</translation>
    </message>
    <message>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 oran</translation>
    </message>
    <message>
      <source>Display the image at a 1:1 scale</source>
      <translation>Birebir oranla resmi görüntüle</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Öz renk</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Resmi kendi öz renk değer(ler)iyle görüntüle</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Aydınlatılmış renk</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Resmi aydınlatılmış renk(ler) ile görüntüle</translation>
    </message>
    <message>
      <source>Standard</source>
      <translation>Standart</translation>
    </message>
    <message>
      <source>Ready...</source>
      <translation>Hazır...</translation>
    </message>
    <message>
      <source>grey</source>
      <translation>gri</translation>
    </message>
    <message>
      <source>zoom</source>
      <translation>yakınlaş</translation>
    </message>
    <message>
      <source>outside image</source>
      <translation>dış görünüm</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Resim görüntüleyeci</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+106"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Resimler (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <source>Choose an image file to open</source>
      <translation>Açmak için bir görüntü dosyası seçin</translation>
    </message>
    <message>
      <source>Images</source>
      <translation>Resimler</translation>
    </message>
    <message>
      <source>All files</source>
      <translation>Tüm dosyalar</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Resim açarken hata</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Seçilen resim yüklenemedi</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Görüntü</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Image/Gui/Resources/translations/Image_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+94"/>
      <source>Image</source>
      <translation>Görüntü</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Görüntü düzlemini oluştur...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>3B uzayda düzlemsel bir resim oluştur</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation type="obsolete">3B uzayda düzlemsel bir resim oluştur</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-44"/>
      <source>Image</source>
      <translation>Görüntü</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Aç...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Resim görünümünü aç</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+326"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Resmi görüntülemek için tanılanamayan bir renk uzayı seçili</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>Image pixel format</source>
      <translation>Görüntü karecik (piksel) biçimi</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Choose orientation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation type="unfinished">Image plane</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation type="unfinished">XY-Plane</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation type="unfinished">XZ-Plane</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation type="unfinished">YZ-Plane</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Reverse direction</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation type="unfinished">Offset:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Resmi sığdır</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Resmi, görünüme sığacak şekilde uzat</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 oran</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Birebir oranla resmi görüntüle</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation type="obsolete">&amp;Öz renk</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation type="obsolete">Resmi kendi öz renk değer(ler)iyle görüntüle</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation type="obsolete">&amp;Aydınlatılmış renk</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation type="obsolete">Resmi aydınlatılmış renk(ler) ile görüntüle</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standart</translation>
    </message>
    <message>
      <location line="+13"/>
      <source>Ready...</source>
      <translation>Hazır...</translation>
    </message>
    <message>
      <location line="+375"/>
      <source>grey</source>
      <translation>gri</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>yakınlaş</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>dış görünüm</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation type="obsolete">Resim görüntüleyeci</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+117"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Resimler (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location line="-99"/>
      <location line="+41"/>
      <location line="+57"/>
      <source>Choose an image file to open</source>
      <translation>Açmak için bir görüntü dosyası seçin</translation>
    </message>
    <message>
      <location line="-105"/>
      <location line="+41"/>
      <source>Images</source>
      <translation>Resimler</translation>
    </message>
    <message>
      <location line="-36"/>
      <location line="+41"/>
      <source>All files</source>
      <translation>Tüm dosyalar</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error open image</source>
      <translation>Resim açarken hata</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the choosen image</source>
      <translation>Seçilen resim yüklenemedi</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Görüntü</translation>
    </message>
  </context>
</TS>
